@@ -13,7 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import math
 from datetime import datetime
 from hashlib import blake2b
 
@@ -828,10 +828,37 @@ class Vec(ScaleType):
         return data
 
 
-class BitVec(Vec):
-    # TODO: A BitVec that represents an array of bits. The bits are however stored encoded. The difference between this
-    #  * and a normal Bytes would be that the length prefix indicates the number of bits encoded, not the bytes
-    pass
+class BitVec(ScaleType):
+    """
+    A BitVec that represents an array of bits. The bits are however stored encoded. The difference between this
+    and a normal Bytes would be that the length prefix indicates the number of bits encoded, not the bytes
+    """
+    def process(self):
+        length_obj = self.process_type('Compact<u32>')
+
+        total = math.ceil(length_obj.value / 8)
+
+        value_int = int.from_bytes(self.get_next_bytes(total), byteorder='little')
+
+        return [bool(value_int & (1 << n)) for n in range(length_obj.value)]
+
+    def process_encode(self, value):
+
+        if type(value) is not list:
+            raise ValueError("Provided value is not a list of booleans")
+
+        if len(value) == 0:
+            return ScaleBytes(b'\x00')
+
+        int_value = sum(v << i for i, v in enumerate(value))
+
+        # encode the length in a compact u32
+        compact_obj = CompactU32()
+        data = compact_obj.encode(len(value))
+
+        byte_length = math.ceil(len(value) / 8)
+
+        return data + int_value.to_bytes(length=byte_length, byteorder='little')
 
 
 class GenericAddress(ScaleType):
